(Steve Dougherty)
2013-06-04: Rename "own identity" to "local identity". Rename "own identity" to "local identity". More idiomatic English.
diff --git a/infocalypse/__init__.py b/infocalypse/__init__.py
--- a/infocalypse/__init__.py
+++ b/infocalypse/__init__.py
@@ -387,7 +387,7 @@ def infocalypse_create(ui_, repo, **opts
nick_prefix, repo_desc = opts['wot'].split('/', 1)
import wot
- attributes = wot.resolve_own_identity(ui_, nick_prefix)
+ attributes = wot.resolve_local_identity(ui_, nick_prefix)
if attributes is None:
# Something went wrong; the function already printed an error.
return
diff --git a/infocalypse/wot.py b/infocalypse/wot.py
--- a/infocalypse/wot.py
+++ b/infocalypse/wot.py
@@ -3,18 +3,18 @@ import fcp
# Support for querying WoT for own identities and identities meeting various
# criteria.
-def resolve_own_identity(ui, nickname_prefix=None):
+def resolve_local_identity(ui, nickname_prefix=None):
"""
Mercurial ui for status updates and error messages.
Nickname prefix should be enough to not be ambiguous.
# TODO: Does not support duplicate nicknames between own identities.
# Could support looking at identity to resolve further.
Returns a dictionary of the nickname, insert and request URIs,
and identity that match the given criteria.
In the case of an error prints a message and returns None.
"""
- ui.status("Querying WoT for own identities.\n")
+ ui.status("Querying WoT for local identities.\n")
node = fcp.FCPNode()
response =\
node.fcpPluginMessage(async=False,
@@ -3,18 +3,18 @@ import fcp
Mercurial ui for status updates and error messages.
Nickname prefix should be enough to not be ambiguous.
- # TODO: Does not support duplicate nicknames between own identities.
+ # TODO: Does not support duplicate nicknames between local identities.
# Could support looking at identity to resolve further.
Returns a dictionary of the nickname, insert and request URIs,